@@ -5,7 +5,7 @@ from convisoappsec.flowcli.context import pass_flow_context
 from convisoappsec.flow.version_searchers import SortedByVersioningStyle
 from convisoappsec.flow.version_control_system_adapter import GitAdapter
 from convisoappsec.flowcli import help_option
-from convisoappsec.flowcli.common import project_code_option
+from convisoappsec.flowcli.common import project_code_option, on_http_error
 from convisoappsec.flowcli.deploy.create.context import pass_create_context
 
 from convisoappsec.flowcli.deploy.create.with_.tag_tracker.context import (
@@ -95,17 +95,23 @@ def versioning_style(
 
         flow = flow_context.create_flow_api_client()
 
+        authors_data = git_adapter.get_commit_authors_by_range(
+            previous_commit, current_commit
+        )
+
         deploy = flow.deploys.create(
             project_code,
             current_version=current_version,
             previous_version=previous_version,
             diff_content=diff_content,
             metrics=deploy_metrics,
-            project_metrics=project_metrics(repository_dir)
+            project_metrics=project_metrics(repository_dir),
+            commit_authors=authors_data
         )
 
         click.echo(
             create_context.output_formatter.format(deploy)
         )
     except Exception as e:
+        on_http_error(e)
         raise click.ClickException(str(e)) from e
