@@ -1,16 +1,25 @@
-import click
+import os
 
+import click
+import click_log
+from convisoappsec.flow import api
+from convisoappsec.flow.util.ci_provider import CIProvider
+from convisoappsec.flowcli import help_option
+from convisoappsec.flowcli.common import process_ci_provider_option
+from convisoappsec.flowcli.iac.entrypoint import iac
+from convisoappsec.logger import LOGGER
 from convisoappsec.version import __version__
 
-from convisoappsec.flow import api
-
+from .ast import ast
+from .context import pass_flow_context
 from .deploy import deploy
 from .finding import finding
 from .sast import sast
 from .sca import sca
 from .vulnerability import vulnerability
-from .context import pass_flow_context
-from convisoappsec.flowcli import help_option
+from .assets import assets
+
+click_log.basic_config(LOGGER)
 
 
 def api_url_autocompletion(*args, **kargs):
@@ -22,6 +31,7 @@ def api_url_autocompletion(*args, **kargs):
 
 
 @click.group()
+@click_log.simple_verbosity_option(LOGGER, '-l', '--verbosity')
 @click.option(
     '-k',
     '--api-key',
@@ -49,6 +59,18 @@ def api_url_autocompletion(*args, **kargs):
     is_flag=True,
     help='HTTPS requests to untrusted hosts is enable.',
 )
+@click.option(
+    '-c',
+    '--ci-provider-name',
+    show_envvar=True,
+    envvar="CI_PROVIDER_NAME",
+    type=click.Choice(CIProvider.names()),
+    default=None,
+    show_default=True,
+    required=False,
+    help="The ci provider used by project. "
+         "When not informed, an automatic search will be performed."
+)
 @help_option
 @click.version_option(
     __version__,
@@ -57,17 +79,24 @@ def api_url_autocompletion(*args, **kargs):
     message=('%(prog)s %(version)s')
 )
 @pass_flow_context
-def cli(flow_context, api_key, api_url, api_insecure):
+def cli(flow_context, api_key, api_url, api_insecure, ci_provider_name):
     flow_context.key = api_key
     flow_context.url = api_url
     flow_context.insecure = api_insecure
 
+    ci_provider = process_ci_provider_option(ci_provider_name, os.environ)
+    flow_context.ci_provider = ci_provider
+    LOGGER.debug('CI provider name detected: {}'.format(flow_context.ci_provider.name))
+
 
 cli.add_command(deploy)
 cli.add_command(finding)
 cli.add_command(sast)
 cli.add_command(sca)
 cli.add_command(vulnerability)
+cli.add_command(ast)
+cli.add_command(iac)
+cli.add_command(assets)
 
 cli.epilog = '''
   Run flow COMMAND --help for more information on a command.
